Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenkernel/BKE_mesh_fair.h')
-rw-r--r--source/blender/blenkernel/BKE_mesh_fair.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/blenkernel/BKE_mesh_fair.h b/source/blender/blenkernel/BKE_mesh_fair.h
index 9d94c692858..e5b92b795c0 100644
--- a/source/blender/blenkernel/BKE_mesh_fair.h
+++ b/source/blender/blenkernel/BKE_mesh_fair.h
@@ -29,10 +29,10 @@ void BKE_bmesh_prefair_and_fair_verts(struct BMesh *bm,
bool *affect_verts,
eMeshFairingDepth depth);
/* This function can optionally use the MVert coordinates of deform_mverts to read and write the
* fairing result. When NULL, the function will use mesh->mverts directly. */
void BKE_mesh_prefair_and_fair_verts(struct Mesh *mesh,
- struct MVert *deform_mverts,
+ float (*deform_positions)[3],
bool *affect_verts,
eMeshFairingDepth depth);
@@ -29,10 +29,10 @@ void BKE_bmesh_prefair_and_fair_verts(struct BMesh *bm,
bool *affect_verts,
eMeshFairingDepth depth);
-/* This function can optionally use the MVert coordinates of deform_mverts to read and write the
- * fairing result. When NULL, the function will use mesh->mverts directly. */
+/* This function can optionally use the vertex coordinates of deform_mverts to read and write the
+ * fairing result. When NULL, the function will use mesh positions directly. */
void BKE_mesh_prefair_and_fair_verts(struct Mesh *mesh,